@@ -1,6 +1,6 @@
 #!/usr/bin/env python2.3
 
-__version__ = "$Revision: 1.1 $"
+__version__ = "$Revision: 1.3 $"
 
 import tempfile
 
@@ -20,17 +20,21 @@ def _init_job_array():
 def _init_job():
     jobid = None
     jobname = None
-    
-    def local(filename, mode="r", host=poly.headnode, force=False): # imitate for better error-checking
+
+    def local(filename, mode="r", host=poly.headnode, force=False):
+        # imitate for better error-checking
         return filename
 
     gettempdir = tempfile.gettempdir
-    NamedTemporaryFile = tempfile.NamedTemporaryFile
+    # XXX: replace with Py2.5 partial
+    NamedTemporaryFile = poly._fixargs(tempfile.NamedTemporaryFile,
+                                       suffix=".poly")
     TemporaryFile = tempfile.TemporaryFile
 
     _localfile_cmds = poly._init_localfile_cmds(default=["scp"])
 
-    return jobid, jobname, local, gettempdir, NamedTemporaryFile, TemporaryFile, _localfile_cmds
+    return (jobid, jobname, local, gettempdir,
+            NamedTemporaryFile, TemporaryFile, _localfile_cmds)
 
 def _init_headnode():
     return "localhost"
